#
# spec file for package libteam
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libteam
Version:        1.18
Release:        0
Summary:        Utilities for controlling 802.1AX team network device
License:        LGPL-2.1+
Group:          System/Kernel
Url:            http://libteam.org/

#Git-Web:	https://github.com/jpirko/libteam
#Git-Clone:	git://github.com/jpirko/libteam
Source:         http://libteam.org/files/%name-%version.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  doxygen
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libdaemon)
BuildRequires:  pkgconfig(libnl-3.0) >= 3.2.0
BuildRequires:  pkgconfig(libnl-cli-3.0) >= 3.2.0
BuildRequires:  pkgconfig(libnl-genl-3.0) >= 3.2.0
BuildRequires:  pkgconfig(libnl-route-3.0) >= 3.2.0
%if 0%{?suse_version} >= 1220
BuildRequires:  systemd-rpm-macros
%endif

%description
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n libteam5
Summary:        Library for controlling 802.1AX team network device
Group:          System/Libraries

%description -n libteam5
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n libteamdctl0
Summary:        Library for controlling the team network device daemon
Group:          System/Libraries

%description -n libteamdctl0
Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package devel
Summary:        Development files for libteam
Group:          Development/Libraries/C and C++
Requires:       libteam5 = %version
Requires:       libteamdctl0 = %version

%description devel
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

This package contains the development headers for the libteam and
libteamdctl libraries.

%package tools
Summary:        Utilities for controlling team network devices
Group:          System/Daemons

%description tools
This package contains frontends to libteam that allow changing
the (team-specific) properties of team devices.
(The general configuration of network devices can be done
through using iproute.)

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n python-libteam
Summary:        Python bindings for libteam
Group:          Development/Languages/Python

%description -n python-libteam
This package should be installed if you want to develop Python
programs that will manipulate team network devices.

%prep
%setup -q

%build
%configure --includedir="%_includedir/pkg/%name" --bindir="%_sbindir" \
	--disable-static
# Use CFLAGS= to kill -Werror
make %{?_smp_mflags} CFLAGS="%optflags"

pushd binding/python/;
python ./setup.py build;
popd;

%install
b="%buildroot";
make install DESTDIR="$b";
pushd binding/python/;
python ./setup.py install --root="$b" --prefix="%_prefix";
popd;

rm -f "$b/%_libdir"/*.la
%if 0%{?_unitdir:1}
mkdir -p "$b/%_unitdir";
install -pm0644 teamd/redhat/systemd/*.service "$b/%_unitdir/";
%endif

%check
make check

%pre tools
%if 0%{?_unitdir:1}
%service_add_pre teamd@.service
%endif

%post tools
%if 0%{?_unitdir:1}
%service_add_post teamd@.service
%endif

%preun tools
%if 0%{?_unitdir:1}
%service_del_preun teamd@.service
%endif

%postun tools
%if 0%{?_unitdir:1}
%service_del_postun teamd@.service
%endif

%post   -n libteam5 -p /sbin/ldconfig
%postun -n libteam5 -p /sbin/ldconfig
%post   -n libteamdctl0 -p /sbin/ldconfig
%postun -n libteamdctl0 -p /sbin/ldconfig

%files -n libteam5
%defattr(-,root,root)
%_libdir/libteam.so.5*

%files -n libteamdctl0
%defattr(-,root,root)
%_libdir/libteamdctl.so.0*

%files devel
%defattr(-,root,root)
%_includedir/pkg/
%_libdir/libteam.so
%_libdir/libteamdctl.so
%_libdir/pkgconfig/libteam*.pc

%files tools
%defattr(-,root,root)
%_sbindir/bond2team
%_sbindir/team*
%_mandir/man1/*
%_mandir/man5/*
%_mandir/man8/*
%if 0%{?_unitdir:1}
%_unitdir
%endif

%files -n python-libteam
%defattr(-,root,root)
%python_sitearch/*

%changelog
